#pragma once

#include "common/common_pch.h"

using MediaTime = int64_t;
using binary    = uint8_t;
